@@ -54,7 +54,7 @@ If you want to be a bit more restrictive with SNMP write access to the router, t
 The above configuration grants SNMP read-write only to 10.37.3.5 (the smokeping host) and only to the ciscoRttMon MIB tree. The probe does not need access to SNMP variables outside the RttMon tree.
 DOC
 		bugs => <<DOC,
-The probe establishes unnecessary connections, i.e. more than configured in the "pings" variable, because the RTTMon MIB only allows to set a total time for all connections in one measurement run (one "life"). Currently the probe sets the life duration to "pings"*2+3 seconds (2 secs is the timeout value hardcoded into this probe). 
+The probe establishes unnecessary connections, i.e. more than configured in the "pings" variable, because the RTTMon MIB only allows to set a total time for all connections in one measurement run (one "life"). Currently the probe sets the life duration to "pings"*5+3 seconds (5 secs is the timeout value hardcoded into this probe). 
 DOC
 		see_also => <<DOC,
 L<http://oss.oetiker.ch/smokeping/>
@@ -70,7 +70,7 @@ DOC
 	}
 }
 
-my $pingtimeout =2;
+my $pingtimeout = 5;
 
 sub new($$$)
 {
@@ -274,6 +274,12 @@ The (optional) port parameter lets you configure the destination TCP
 port on the host. The default is the http port 80.
 DOC
 		},
+        timeout => {
+             _re => '\d+', 
+             _example => 15,
+             _default => $pingtimeout+10,
+             _doc => "How long a single RTTMon TcpConnect 'ping' take at maximum plus 10 seconds to spare. Since we control our own timeout the only purpose of this is to not have us killed by the ping method from basefork.",
+        },
 		iosint => {
 			_example => '10.33.22.11',
 			_doc => <<DOC,
