@@ -32,6 +32,9 @@ your system yet, you can get a slightly enhanced version from L<www.smokeping.or
   
 The (optional) B<packetsize> option lets you configure the packetsize for the pings sent.
 
+Since version 3.3 fping sends its statistics to stdout. Set B<usestdout> to 'true'
+so make smokeping read stdout instead of stderr.
+
 In B<blazemode>, FPing sends one more ping than requested, and discards
 the first RTT value returned as it's likely to be an outlier.
 
@@ -64,8 +67,8 @@ sub new($$$)
     	my $binary = join(" ", $self->binary);
 	my $testhost = $self->testhost;
         my $return = `$binary -C 1 $testhost 2>&1`;
-        $self->{enable}{S} = (`$binary -h 2>&1` =~ /\s-S\s/);
-        $self->{enable}{O} = (`$binary -h 2>&1` =~ /\s-O\s/);
+        $self->{enable}{S} = (`$binary -h 2>&1` =~ /\s-S[,\s]/);
+        $self->{enable}{O} = (`$binary -h 2>&1` =~ /\s-O[,\s]/);
         croak "ERROR: fping ('$binary -C 1 $testhost') could not be run: $return"
             if $return =~ m/not found/;
         croak "ERROR: FPing must be installed setuid root or it will not work\n" 
@@ -116,6 +119,7 @@ sub ping ($){
     # pinging nothing is pointless
     return unless @{$self->addresses};
     my @params = () ;
+    push @params, "-$self->{properties}{protocol}";
     push @params, "-b$self->{properties}{packetsize}" if $self->{properties}{packetsize};
     push @params, "-t" . int(1000 * $self->{properties}{timeout}) if $self->{properties}{timeout};
     push @params, "-i" . int(1000 * $self->{properties}{mininterval});
@@ -142,7 +146,8 @@ sub ping ($){
     $self->do_debug("Executing @cmd");
     my $pid = open3($inh,$outh,$errh, @cmd);
     $self->{rtts}={};
-    while (<$errh>){
+    my $fh = ( $self->{properties}{usestdout} || '') eq 'true' ? $outh : $errh;
+    while (<$fh>){
         chomp;
 	$self->do_debug("Got fping output: '$_'");
         next unless /^\S+\s+:\s+[-\d\.]/; #filter out error messages from fping
@@ -193,6 +198,19 @@ sub probevars {
 			_example => 'true',
 			_doc => "Send an extra ping and then discarge the first answer since the first is bound to be an outliner.",
 
+		},
+		protocol => {
+			_re => '(4|6)',
+			_example => '4',
+			_default => '4',
+			_doc => "Choose if the ping should use IPv4 or IPv6.",
+
+		},
+		usestdout => {
+			_re => '(true|false)',
+			_example => 'true',
+			_doc => "Listen for FPing output on stdout instead of stderr ... (version 3.3+ sends its statistics on stdout).",
+
 		},
 		timeout => {
 			_re => '(\d*\.)?\d+',
